==> haskell-brittany-0.14.0.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-brittany.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 brittany
version:              0.14.0.2
visibility:           public
id:                   brittany-0.14.0.2-AeUespte9YT2UaMTLu0Y4p
key:                  brittany-0.14.0.2-AeUespte9YT2UaMTLu0Y4p
license:              AGPL-3.0-only
copyright:
    Copyright (C) 2016-2019 Lennart Spitzner
    Copyright (C) 2019 PRODA LTD

maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/brittany/
synopsis:             Haskell source code formatter
description:
    See <https://github.com/lspitzner/brittany/blob/master/README.md the README>.

    If you are interested in the implementation, have a look at <https://github.com/lspitzner/brittany/blob/master/doc/implementation/theory.md this document>;

    The implementation is documented in more detail <https://github.com/lspitzner/brittany/blob/master/doc/implementation/index.md here>.

category:             Language
abi:                  3c82c2a77bbf8f73715ab48fa47d43a8
exposed:              True
exposed-modules:
    Language.Haskell.Brittany Language.Haskell.Brittany.Internal
    Language.Haskell.Brittany.Internal.Backend
    Language.Haskell.Brittany.Internal.BackendUtils
    Language.Haskell.Brittany.Internal.Config
    Language.Haskell.Brittany.Internal.Config.Types
    Language.Haskell.Brittany.Internal.Config.Types.Instances
    Language.Haskell.Brittany.Internal.ExactPrintUtils
    Language.Haskell.Brittany.Internal.LayouterBasics
    Language.Haskell.Brittany.Internal.Layouters.DataDecl
    Language.Haskell.Brittany.Internal.Layouters.Decl
    Language.Haskell.Brittany.Internal.Layouters.Expr
    Language.Haskell.Brittany.Internal.Layouters.IE
    Language.Haskell.Brittany.Internal.Layouters.Import
    Language.Haskell.Brittany.Internal.Layouters.Module
    Language.Haskell.Brittany.Internal.Layouters.Pattern
    Language.Haskell.Brittany.Internal.Layouters.Stmt
    Language.Haskell.Brittany.Internal.Layouters.Type
    Language.Haskell.Brittany.Internal.Obfuscation
    Language.Haskell.Brittany.Internal.ParseModule
    Language.Haskell.Brittany.Internal.Prelude
    Language.Haskell.Brittany.Internal.PreludeUtils
    Language.Haskell.Brittany.Internal.Transformations.Alt
    Language.Haskell.Brittany.Internal.Transformations.Columns
    Language.Haskell.Brittany.Internal.Transformations.Floating
    Language.Haskell.Brittany.Internal.Transformations.Indent
    Language.Haskell.Brittany.Internal.Transformations.Par
    Language.Haskell.Brittany.Internal.Types
    Language.Haskell.Brittany.Internal.Utils
    Language.Haskell.Brittany.Main Paths_brittany

import-dirs:          /usr/lib/ghc-9.0.2/site-local/brittany-0.14.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/brittany-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-brittany
hs-libraries:         HSbrittany-0.14.0.2-AeUespte9YT2UaMTLu0Y4p
depends:
    Cabal-3.4.1.0 aeson-2.1.0.0-3wSqLBA0fU13NhfXDmBpwT base-4.15.1.0
    butcher-1.3.3.2-DAvFNMLnHRBAPbKoeIew65 bytestring-0.10.12.1
    cmdargs-0.10.21-5dEStss8OK87s5amCxsPTV containers-0.6.4.1
    czipwith-1.0.1.4-EXJR4bf7ZgFBXkogwUHX2e
    data-tree-print-0.1.0.2-JhYvukZXKZ5nSVP89hjg3 deepseq-1.4.5.0
    directory-1.3.6.2 extra-1.7.12-DPTGYhuNp118MPDFhQYU8g
    filepath-1.4.2.1 ghc-9.0.2 ghc-boot-9.0.2 ghc-boot-th-9.0.2
    ghc-exactprint-0.6.4-6vngUIjPAGkJCcW5GIC4MS
    monad-memo-0.5.4-6MDCyrtkO0c2Oetoh4tx57 mtl-2.2.2
    multistate-0.8.0.4-AzRTaDWXjer2BOuAAxM0AD pretty-1.1.3.6
    random-1.2.1.1-LHneN0qmdBg2HhYYKMDrs5
    safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q
    strict-0.4.0.1-2mY0lBYSyne2S4tzH93Ukt
    syb-0.7.2.2-JvKYfJw95RM7Y4GXhTvfdV text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-Bz3m6aJYQrB6IKo2ZbSAY5
    yaml-0.11.8.0-EFN1CMgVIdSAIGSdgvEPUP

haddock-interfaces:   /usr/share/doc/haskell-brittany/html/brittany.haddock
haddock-html:         /usr/share/doc/haskell-brittany/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-brittany-0.14.0.2-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-brittany.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 brittany
version:              0.14.0.2
visibility:           public
id:                   brittany-0.14.0.2-AMYWoFNEqgKPABcCqrT3L
key:                  brittany-0.14.0.2-AMYWoFNEqgKPABcCqrT3L
license:              AGPL-3.0-only
copyright:
    Copyright (C) 2016-2019 Lennart Spitzner
    Copyright (C) 2019 PRODA LTD

maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/brittany/
synopsis:             Haskell source code formatter
description:
    See <https://github.com/lspitzner/brittany/blob/master/README.md the README>.

    If you are interested in the implementation, have a look at <https://github.com/lspitzner/brittany/blob/master/doc/implementation/theory.md this document>;

    The implementation is documented in more detail <https://github.com/lspitzner/brittany/blob/master/doc/implementation/index.md here>.

category:             Language
abi:                  50fd603dffe913fd935e3ca7a2aff617
exposed:              True
exposed-modules:
    Language.Haskell.Brittany Language.Haskell.Brittany.Internal
    Language.Haskell.Brittany.Internal.Backend
    Language.Haskell.Brittany.Internal.BackendUtils
    Language.Haskell.Brittany.Internal.Config
    Language.Haskell.Brittany.Internal.Config.Types
    Language.Haskell.Brittany.Internal.Config.Types.Instances
    Language.Haskell.Brittany.Internal.ExactPrintUtils
    Language.Haskell.Brittany.Internal.LayouterBasics
    Language.Haskell.Brittany.Internal.Layouters.DataDecl
    Language.Haskell.Brittany.Internal.Layouters.Decl
    Language.Haskell.Brittany.Internal.Layouters.Expr
    Language.Haskell.Brittany.Internal.Layouters.IE
    Language.Haskell.Brittany.Internal.Layouters.Import
    Language.Haskell.Brittany.Internal.Layouters.Module
    Language.Haskell.Brittany.Internal.Layouters.Pattern
    Language.Haskell.Brittany.Internal.Layouters.Stmt
    Language.Haskell.Brittany.Internal.Layouters.Type
    Language.Haskell.Brittany.Internal.Obfuscation
    Language.Haskell.Brittany.Internal.ParseModule
    Language.Haskell.Brittany.Internal.Prelude
    Language.Haskell.Brittany.Internal.PreludeUtils
    Language.Haskell.Brittany.Internal.Transformations.Alt
    Language.Haskell.Brittany.Internal.Transformations.Columns
    Language.Haskell.Brittany.Internal.Transformations.Floating
    Language.Haskell.Brittany.Internal.Transformations.Indent
    Language.Haskell.Brittany.Internal.Transformations.Par
    Language.Haskell.Brittany.Internal.Types
    Language.Haskell.Brittany.Internal.Utils
    Language.Haskell.Brittany.Main Paths_brittany

import-dirs:          /usr/lib/ghc-9.0.2/site-local/brittany-0.14.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/brittany-0.14.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-brittany
hs-libraries:         HSbrittany-0.14.0.2-AMYWoFNEqgKPABcCqrT3L
depends:
    Cabal-3.4.1.0 aeson-2.1.2.1-A4BCifdqKBRKymWAxMJ7G4 base-4.15.1.0
    butcher-1.3.3.2-9AZDJ7VaUwEj6pdLAhiOv bytestring-0.10.12.1
    cmdargs-0.10.22-LMGehiIpWZC4X4EZqKH5Yu containers-0.6.4.1
    czipwith-1.0.1.4-EXJR4bf7ZgFBXkogwUHX2e
    data-tree-print-0.1.0.2-Fw1NCOJySj15KgHRLK9xT0 deepseq-1.4.5.0
    directory-1.3.6.2 extra-1.7.13-HYX6gpOPDmAIHqUj1ljVuZ
    filepath-1.4.2.1 ghc-9.0.2 ghc-boot-9.0.2 ghc-boot-th-9.0.2
    ghc-exactprint-0.6.4-Avj2q5Q1CIIJKbxhQ1a4Zt
    monad-memo-0.5.4-JoorxgNsAQY5Nq2ndAOTaQ mtl-2.2.2
    multistate-0.8.0.4-JuXGNkw9jFACfSz3go5xpN pretty-1.1.3.6
    random-1.2.1.1-K0OGGZ2RgxUBJhcMzCddDt
    safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q
    strict-0.4.0.1-DqIvrYJvHoWHqER1V0TQ0H
    syb-0.7.2.3-ItYotKJTU3VJfC5cskyLmn text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-BOezg2zuMGrKMCjK6N2ijG
    yaml-0.11.11.2-HMJi93sq55j29LTuvNA0C1

haddock-interfaces:   /usr/share/doc/haskell-brittany/html/brittany.haddock
haddock-html:         /usr/share/doc/haskell-brittany/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
